@@ -91,9 +91,12 @@ class MainDlg(MainFrm):
             font = self.listToFont(get_config("font"))
             self.question_text.setFont(font)
             self.answer_text.setFont(font)
-
-        path = os.path.join(sys.exec_prefix, "lib", "python"+sys.version[:3],
-                            "site-packages","pyqt_memaid", "pixmaps")
+            
+        if sys.platform == "win32":
+            path = "pixmaps"
+        else:
+            path = os.path.join(sys.exec_prefix, "lib", "python"+sys.version[:3],
+                                "site-packages","pyqt_memaid", "pixmaps")
 
         self.fileNewAction.setIconSet \
              (QIconSet(QPixmap(os.path.join(path,"filenew.png"))))
@@ -119,6 +122,8 @@ class MainDlg(MainFrm):
         self.setLearningModeAction.setIconSet \
              (QIconSet(QPixmap(os.path.join(path,"configure.png"))))
 
+        self.setIcon(QPixmap(os.path.join(path,"memaid.png")))
+
         self.need_to_train = False
 
         if item_id != None:
@@ -454,7 +459,7 @@ class MainDlg(MainFrm):
     def helpAbout(self):
         QMessageBox.about(None,
             self.trUtf8("PyQt MemAid"),
-            self.trUtf8("PyQt MemAid 0.2.2\n\n"+
+            self.trUtf8("PyQt MemAid 0.2.3\n\n"+
                         "Author: Peter Bienstman\n"+
                         "original MemAid: David Calinski"))
 
