@@ -350,10 +350,12 @@ def load_database(path):
 
     try:    
         infile = file(path)
-    
-        time_of_start = cPickle.load(infile)
-        categories    = cPickle.load(infile)
-        items         = cPickle.load(infile)
+
+        db = cPickle.load(infile)
+        
+        time_of_start = db[0]
+        categories    = db[1]
+        items         = db[2]
 
         infile.close()
     except:
@@ -390,11 +392,8 @@ def save_database(path):
     try:
         outfile = file(path,'w')
 
-        bin = True
-
-        cPickle.dump(time_of_start, outfile, bin)
-        cPickle.dump(categories, outfile, bin)
-        cPickle.dump(items, outfile, bin)
+        db = [time_of_start, categories, items]
+        cPickle.dump(db, outfile)
 
         outfile.close()
     except:
@@ -449,7 +448,7 @@ def list_is_loaded():
 #
 # escape
 #
-#   Escapes litteral < (unamatched tag) and new line from string.
+#   Escapes literal < (unmatched tag) and new line from string.
 #
 ##############################################################################
 
@@ -652,6 +651,11 @@ def import_XML(filename, default_cat_name):
 
     global import_items, categories, category_by_name
 
+    # If no database is active, create one.
+
+    if not time_of_start:
+        new_database(config["path"])
+
     # Create default category if necessary.
 
     if default_cat_name not in category_by_name.keys():
